#
# Conditional build:
%bcond_without	tests		# build without tests

%if "%{pld_release}" == "ac"
# add suffix, but allow ccache, etc in ~/.rpmmacros
%{expand:%%define	__cc	%(echo '%__cc' | sed -e 's,-gcc,-gcc4,')}
%{expand:%%define	__cxx	%(echo '%__cxx' | sed -e 's,-g++,-g++4,')}
%{expand:%%define	__cpp	%(echo '%__cpp' | sed -e 's,-gcc,-gcc4,')}
%endif

%define		php_name	php%{?php_suffix}
%define		modname	xhp
Summary:	Inline XML For PHP
Name:		%{php_name}-%{modname}
Version:	1.4
Release:	1
License:	PHP 3.01
Group:		Development/Languages/PHP
Source0:	https://github.com/facebook/xhp/archive/%{version}/php-%{modname}-%{version}.tar.gz
# Source0-md5:	98d56ee6b5bc22f76be4106a224c5875
URL:		http://github.com/facebook/xhp/wiki
Patch0:		optflags.patch
BuildRequires:	%{php_name}-devel >= 4:5.2.0
%{?with_tests:BuildRequires:	/usr/bin/php}
# if you use git checkout:
#BuildRequires:	bison >= 2.3
#BuildRequires:	flex >= 2.5.35
BuildRequires:	libstdc++-devel >= 5:4.0
%{?with_tests:BuildRequires:	php-pcre}
BuildRequires:	re2c >= 0.13.5
BuildRequires:	rpm >= 4.4.9-56
BuildRequires:	rpmbuild(macros) >= 1.666
%{?requires_php_extension}
# gcc4 might be installed, but not current __cc
%if "%(echo %{cc_version} | cut -d. -f1,2)" < "4.0"
BuildRequires:	__cc >= 4.0
%endif
Requires(post,postun):	/sbin/ldconfig
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
XHP is a PHP extension which augments the syntax of the language such
that XML document fragments become valid PHP expressions. This allows
you to use PHP as a stricter templating engine and offers much more
straightforward implementation of reusable components.

%package devel
Summary:	Header files for xhp
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki xhp
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	php-devel >= 4:5.2.0

%description devel
Header files for xhp.

%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1

# disable failing tests
mv tests/idx-01.phpt{,.fail}
mv tests/trait.phpt{,.fail}

%ifarch alpha sparc ppc
%{__sed} -i -e 's/-minline-all-stringops//' xhp/Makefile
%endif

%build
%{__make} -C xhp \
	libdir=%{_libdir} \
	CXX="%{__cxx}" \
	OPTFLAGS="%{rpmcxxflags} -fpermissive"

phpize
%configure
%{__make} \
	CC="%{__cc}" \
	CXX="%{__cxx}" \
	CXXFLAGS="%{rpmcxxflags} -fpermissive"

%if %{with tests}
cat <<'EOF' > run-tests.sh
#!/bin/sh
export NO_INTERACTION=1 REPORT_EXIT_STATUS=1 MALLOC_CHECK_=2
unset TZ LANG LC_ALL || :
%{__make} test \
	RUN_TESTS_SETTINGS="-q $*"
EOF
chmod +x run-tests.sh
./run-tests.sh -w failed.log -s test.log
test ! -s failed.log
%endif

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	EXTENSION_DIR=%{php_extensiondir} \
	INSTALL_ROOT=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d
cat <<'EOF' > $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d/%{modname}.ini
; Enable %{modname} extension module
extension=%{modname}.so
EOF

install -d $RPM_BUILD_ROOT%{php_data_dir}/xhp
cp -a php-lib/* $RPM_BUILD_ROOT%{php_data_dir}/xhp
install -p xhp/libxhp.so $RPM_BUILD_ROOT%{_libdir}

# files used by hiphop-php
install -d $RPM_BUILD_ROOT{%{_libdir},%{_includedir}}
cp -p xhp/libxhp.a $RPM_BUILD_ROOT%{_libdir}
cp -p xhp/xhp_preprocess.hpp $RPM_BUILD_ROOT%{_includedir}

%clean
rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig
%php_webserver_restart

%postun
/sbin/ldconfig
if [ "$1" = 0 ]; then
	%php_webserver_restart
fi

%files
%defattr(644,root,root,755)
%doc README.textile INSTALL
%config(noreplace) %verify(not md5 mtime size) %{php_sysconfdir}/conf.d/%{modname}.ini
%attr(755,root,root) %{php_extensiondir}/%{modname}.so
%{_libdir}/libxhp.so
%{php_data_dir}/xhp

%files devel
%defattr(644,root,root,755)
%{_includedir}/xhp_preprocess.hpp
%{_libdir}/libxhp.a
%changelog
* Sat Nov 23 2013 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/php-xhp.git;a=log;h=master

* Sat Oct 05 2013 Elan Ruusamäe <glen@delfi.ee> 0ae8397
fix test checks, disable failing tests

* Sat Oct 05 2013 Elan Ruusamäe <glen@delfi.ee> 40ffe40
fix library packaging, there are two shared libs, libxhp and xhp php extension

* Sat Oct 05 2013 Elan Ruusamäe <glen@delfi.ee> bf17b0a
allow building for multiple php versions

* Sat Oct 05 2013 Elan Ruusamäe <glen@delfi.ee> 63bc4ce
up to 1.4; supports php 5.5

* Wed Aug 08 2012 Jan Rękorajski <baggins@pld-linux.org> c33315e
-fpermissive is needed to compile it eith gcc 4.7
Release 10

* Mon Aug 06 2012 Elan Ruusamäe <glen@delfi.ee> 158a42c
- release 9 (by relup.sh)

* Mon Jul 25 2011 Elan Ruusamäe <glen@pld-linux.org> 44edbd7
- package static xhp library

* Mon Jul 25 2011 Elan Ruusamäe <glen@pld-linux.org> cc51742
- symlink typo

* Mon Jul 25 2011 Elan Ruusamäe <glen@pld-linux.org> 3dd4785
- package xhp_preprocess.hpp in a way hiphop-php wants it

* Mon Jul 25 2011 Elan Ruusamäe <glen@pld-linux.org> 35491a3
- package -lxhp

* Sat Jan 22 2011 sparky <sparky@pld-linux.org> 7302cb2
- tests BR: /usr/bin/php, php-pcre
- failed.log should be empty -- inverted test condition

* Sun Dec 12 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> db26f31
- release 3

* Sat Dec 11 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 0df0425
- release 2

* Sun Oct 31 2010 Elan Ruusamäe <glen@pld-linux.org> bbeecd3
- -minline-all-stringops also missing on alpha

* Sun Oct 31 2010 Elan Ruusamäe <glen@pld-linux.org> dbff0d3
- catch tests failure

* Sun Oct 31 2010 Elan Ruusamäe <glen@pld-linux.org> 09024a1
- sparc and ppc have no -minline-all-stringops

* Sun Oct 31 2010 Elan Ruusamäe <glen@pld-linux.org> 4c4f9a1
- package also php lib

* Sun Oct 31 2010 Elan Ruusamäe <glen@pld-linux.org> 586950e
- build with gcc4 on ac

* Sun Oct 31 2010 Elan Ruusamäe <glen@pld-linux.org> d6e9691
- it's libstdc++ dep, correct gcc epoch

* Sun Oct 31 2010 Elan Ruusamäe <glen@pld-linux.org> 6e3d2a7
- pass optflags

